@@ -19,17 +19,17 @@
 
 #include "informationpanelcontent.h"
 
-#include <KFileItem>
 #include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
-#include <KJobWidgets>
 #include <KIconEffect>
 #include <KIconLoader>
-#include <QIcon>
+#include <KJobWidgets>
 #include <KLocalizedString>
-#include <QMenu>
 #include <KSeparator>
 #include <KStringHandler>
+
+#include <QIcon>
+#include <QMenu>
 #include <QTextDocument>
 
 #ifndef HAVE_BALOO
@@ -43,18 +43,12 @@
 
 #include <Phonon/BackendCapabilities>
 #include <Phonon/MediaObject>
-#include <Phonon/SeekSlider>
 
-#include <QEvent>
 #include <QLabel>
-#include <QPixmap>
-#include <QResizeEvent>
 #include <QScrollArea>
 #include <QTextLayout>
-#include <QTextLine>
 #include <QTimer>
 #include <QVBoxLayout>
-#include <QFontDatabase>
 #include <QStyle>
 
 #include "dolphin_informationpanelsettings.h"
@@ -65,14 +59,14 @@
 InformationPanelContent::InformationPanelContent(QWidget* parent) :
     QWidget(parent),
     m_item(),
-    m_previewJob(0),
-    m_outdatedPreviewTimer(0),
-    m_preview(0),
-    m_phononWidget(0),
-    m_nameLabel(0),
-    m_metaDataWidget(0),
-    m_metaDataArea(0),
-    m_placesItemModel(0)
+    m_previewJob(nullptr),
+    m_outdatedPreviewTimer(nullptr),
+    m_preview(nullptr),
+    m_phononWidget(nullptr),
+    m_nameLabel(nullptr),
+    m_metaDataWidget(nullptr),
+    m_metaDataArea(nullptr),
+    m_placesItemModel(nullptr)
 {
     parent->installEventFilter(this);
 
@@ -107,7 +101,7 @@ InformationPanelContent::InformationPanelContent(QWidget* parent) :
     m_nameLabel->setFont(font);
     m_nameLabel->setTextFormat(Qt::PlainText);
     m_nameLabel->setAlignment(Qt::AlignHCenter);
-    m_nameLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    m_nameLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
 
     const bool previewsShown = InformationPanelSettings::previewsShown();
     m_preview->setVisible(previewsShown);
@@ -171,11 +165,9 @@ void InformationPanelContent::showItem(const KFileItem& item)
         if (isSearchUrl) {
             // in the case of a search-URL the URL is not readable for humans
             // (at least not useful to show in the Information Panel)
-            KIconLoader iconLoader;
-            QPixmap icon = iconLoader.loadIcon(QStringLiteral("nepomuk"),
-                                               KIconLoader::NoGroup,
-                                               KIconLoader::SizeEnormous);
-            m_preview->setPixmap(icon);
+            m_preview->setPixmap(
+                QIcon::fromTheme(QStringLiteral("nepomuk")).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous)
+            );
         } else {
             // try to get a preview pixmap from the item...
 
@@ -191,7 +183,7 @@ void InformationPanelContent::showItem(const KFileItem& item)
             m_previewJob = new KIO::PreviewJob(KFileItemList() << item, QSize(m_preview->width(), m_preview->height()));
             m_previewJob->setScaleType(KIO::PreviewJob::Unscaled);
             m_previewJob->setIgnoreMaximumSize(item.isLocalFile());
-            if (m_previewJob->ui()) {
+            if (m_previewJob->uiDelegate()) {
                 KJobWidgets::setWindow(m_previewJob, this);
             }
 
@@ -235,11 +227,9 @@ void InformationPanelContent::showItems(const KFileItemList& items)
         m_previewJob->kill();
     }
 
-    KIconLoader iconLoader;
-    QPixmap icon = iconLoader.loadIcon(QStringLiteral("dialog-information"),
-                                       KIconLoader::NoGroup,
-                                       KIconLoader::SizeEnormous);
-    m_preview->setPixmap(icon);
+    m_preview->setPixmap(
+        QIcon::fromTheme(QStringLiteral("dialog-information")).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous)
+    );
     setNameLabelText(i18ncp("@label", "%1 item selected", "%1 items selected", items.count()));
 
     if (m_metaDataWidget) {
@@ -324,10 +314,9 @@ void InformationPanelContent::showIcon(const KFileItem& item)
 {
     m_outdatedPreviewTimer->stop();
     if (!applyPlace(item.targetUrl())) {
-        const QPixmap icon = KIconLoader::global()->loadIcon(item.iconName(), KIconLoader::Desktop,
-                                                             KIconLoader::SizeEnormous, KIconLoader::DefaultState,
-                                                             item.overlays());
-        m_preview->setPixmap(icon);
+        QPixmap pixmap = QIcon::fromTheme(item.iconName()).pixmap(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous);
+        KIconLoader::global()->drawOverlays(item.overlays(), pixmap, KIconLoader::Desktop);
+        m_preview->setPixmap(pixmap);
     }
 }
 
