@@ -19,19 +19,18 @@
 
 #include "kcmdolphinservices.h"
 
+#include "settings/services/servicessettingspage.h"
+
 #include <KPluginFactory>
 #include <KPluginLoader>
 
-#include <settings/services/servicessettingspage.h>
-
 #include <QVBoxLayout>
 
 K_PLUGIN_FACTORY(KCMDolphinServicesConfigFactory, registerPlugin<DolphinServicesConfigModule>(QStringLiteral("dolphinservices"));)
-K_EXPORT_PLUGIN(KCMDolphinServicesConfigFactory("kcmdolphinservices"))
 
 DolphinServicesConfigModule::DolphinServicesConfigModule(QWidget* parent, const QVariantList& args) :
     KCModule(parent),
-    m_services(0)
+    m_services(nullptr)
 {
     Q_UNUSED(args);
 
@@ -42,7 +41,7 @@ DolphinServicesConfigModule::DolphinServicesConfigModule(QWidget* parent, const
 
     m_services = new ServicesSettingsPage(this);
     connect(m_services, &ServicesSettingsPage::changed, this, static_cast<void(DolphinServicesConfigModule::*)()>(&DolphinServicesConfigModule::changed));
-    topLayout->addWidget(m_services, 0, 0);
+    topLayout->addWidget(m_services, 0, nullptr);
 }
 
 DolphinServicesConfigModule::~DolphinServicesConfigModule()
