@@ -20,10 +20,11 @@
 #ifndef KVERSIONCONTROLPLUGIN_H
 #define KVERSIONCONTROLPLUGIN_H
 
-#include <dolphin_export.h>
+#include <dolphinvcs_export.h>
 
-#include <QObject>
 #include <QAction>
+#include <QObject>
+
 class KFileItemList;
 class KFileItem;
 /**
@@ -81,7 +82,7 @@ class KFileItem;
  *
  * @since 4.8
  */
-class DOLPHIN_EXPORT KVersionControlPlugin : public QObject
+class DOLPHINVCS_EXPORT KVersionControlPlugin : public QObject
 {
     Q_OBJECT
 
@@ -144,8 +145,8 @@ public:
         MissingVersion
     };
 
-    KVersionControlPlugin(QObject* parent = 0);
-    virtual ~KVersionControlPlugin();
+    KVersionControlPlugin(QObject* parent = nullptr);
+    ~KVersionControlPlugin() override;
 
     /**
      * Returns the name of the file which stores
@@ -165,16 +166,16 @@ public:
     /**
      * Is invoked after the version control information has been
      * received. It is assured that
-     * KVersionControlPluginV2::beginInfoRetrieval() has been
+     * KVersionControlPlugin::beginRetrieval() has been
      * invoked before.
      */
     virtual void endRetrieval() = 0;
 
     /**
      * @return The version for the item \p item.
-     *         It is assured that KVersionControlPlugin::beginInfoRetrieval() has been
+     *         It is assured that KVersionControlPlugin::beginRetrieval() has been
      *         invoked before and that the file is part of the directory specified
-     *         in beginInfoRetrieval().
+     *         in beginRetrieval().
      */
     virtual ItemVersion itemVersion(const KFileItem& item) const = 0;
 
